pub struct InstallOptions {
pub version: Option<String>,
pub target: Option<String>,
pub prefix: Option<PathBuf>,
pub force: bool,
pub lock_behavior: LockBehavior,
}Fields
version: Option<String>Version to fetch. Defaults to the running binary’s version.
target: Option<String>Target triple to fetch. Defaults to the running binary’s build target.
prefix: Option<PathBuf>Directory to drop sidecars into. Defaults to the directory containing the running zccache executable.
force: boolRe-download even if matching sidecars are already present.
lock_behavior: LockBehaviorWhat to do when another zccache process is already mid-install.